PlCodeLine typedef
One line of code, as the runs it is made of. An empty list is a blank line.
Implementation
typedef PlCodeLine = List<PlCodeToken>;
One line of code, as the runs it is made of. An empty list is a blank line.
typedef PlCodeLine = List<PlCodeToken>;