PlColorFormat enum

The three ways the picker will write a colour back out.

Inheritance
Available extensions

Values

hex → const PlColorFormat

#rrggbb, with an aa pair when the colour is translucent.

rgb → const PlColorFormat

rgb(r, g, b), or rgba(…) when it is translucent.

hsl → const PlColorFormat

hsl(h, s%, l%), or hsla(…) when it is translucent.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PlColorFormat>
A constant List of the values in this enum, in order of their declaration.