side property
Which edge of the trigger it appears on. It flips to the opposite side when there is no room.
Implementation
final PlassSide side;
Which edge of the trigger it appears on. It flips to the opposite side when there is no room.
final PlassSide side;